summaryrefslogtreecommitdiff
path: root/lisp
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2011-11-14 12:23:26 -0800
committerPaul Eggert <eggert@cs.ucla.edu>2011-11-14 12:23:26 -0800
commit8350f087efe62e2ce0ded434534629a56cdc4e8c (patch)
tree9976cec81196a0465269f8669f2a85328570dfd4 /lisp
parent322ad6ec0e773dffefad12df88c98041ca35b427 (diff)
downloademacs-8350f087efe62e2ce0ded434534629a56cdc4e8c.tar.gz
Spelling fixes.
Diffstat (limited to 'lisp')
-rw-r--r--lisp/ChangeLog2
-rw-r--r--lisp/ChangeLog.12
-rw-r--r--lisp/ChangeLog.102
-rw-r--r--lisp/ChangeLog.123
-rw-r--r--lisp/ChangeLog.132
-rw-r--r--lisp/ChangeLog.143
-rw-r--r--lisp/ChangeLog.154
-rw-r--r--lisp/ChangeLog.83
-rw-r--r--lisp/ChangeLog.94
-rw-r--r--lisp/calc/calc-help.el2
-rw-r--r--lisp/calendar/icalendar.el12
-rw-r--r--lisp/cedet/ede/pconf.el2
-rw-r--r--lisp/cedet/mode-local.el2
-rw-r--r--lisp/cedet/semantic/bovine/c.el2
-rw-r--r--lisp/cedet/semantic/bovine/el.el4
-rw-r--r--lisp/cedet/srecode/dictionary.el2
-rw-r--r--lisp/emacs-lisp/eieio-base.el2
-rw-r--r--lisp/emacs-lisp/eieio.el4
-rw-r--r--lisp/emacs-lisp/ert.el20
-rw-r--r--lisp/emulation/viper-util.el2
-rw-r--r--lisp/erc/ChangeLog.0129
-rw-r--r--lisp/erc/ChangeLog.0315
-rw-r--r--lisp/eshell/em-hist.el2
-rw-r--r--lisp/files.el4
-rw-r--r--lisp/gnus/gnus-uu.el2
-rw-r--r--lisp/gnus/gnus-win.el2
-rw-r--r--lisp/info.el2
-rw-r--r--lisp/language/vietnamese.el2
-rw-r--r--lisp/mail/rmail.el6
-rw-r--r--lisp/mail/rmailmm.el2
-rw-r--r--lisp/mpc.el2
-rw-r--r--lisp/net/snmp-mode.el2
-rw-r--r--lisp/net/soap-client.el2
-rw-r--r--lisp/net/xesam.el2
-rw-r--r--lisp/net/zeroconf.el2
-rw-r--r--lisp/org/ChangeLog3
-rw-r--r--lisp/org/org-list.el2
-rw-r--r--lisp/org/org.el2
-rw-r--r--lisp/progmodes/cc-cmds.el4
-rw-r--r--lisp/progmodes/cc-defs.el6
-rw-r--r--lisp/progmodes/gdb-mi.el2
-rw-r--r--lisp/progmodes/idlwave.el2
-rw-r--r--lisp/progmodes/verilog-mode.el4
-rw-r--r--lisp/view.el2
-rw-r--r--lisp/window.el2
-rw-r--r--lisp/woman.el2
46 files changed, 90 insertions, 96 deletions
diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 37b13a7acd8..b84a7b9ded7 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -3876,7 +3876,7 @@
for list)" (bug#6475).
* files.el (file-expand-wildcards): Ignore non-readable
- sub-directories while trying to find matches instead of signalling
+ sub-directories while trying to find matches instead of signaling
an error (bug#6297).
* man.el (Man-reference-regexp): Allow matching possible
diff --git a/lisp/ChangeLog.1 b/lisp/ChangeLog.1
index f1c931589d1..aac6e998a88 100644
--- a/lisp/ChangeLog.1
+++ b/lisp/ChangeLog.1
@@ -1947,7 +1947,7 @@
elements of command-history are expressions.
* simple.el (error):
- Just keep signalling if user tries to continue.
+ Just keep signaling if user tries to continue.
1985-09-07 Richard M. Stallman (rms@mit-prep)
diff --git a/lisp/ChangeLog.10 b/lisp/ChangeLog.10
index a1cba0a9cd9..e0846012697 100644
--- a/lisp/ChangeLog.10
+++ b/lisp/ChangeLog.10
@@ -3516,7 +3516,7 @@
2003-04-23 Stefan Monnier <monnier@cs.yale.edu>
* newcomment.el (comment-normalize-vars): Prompt the user for
- the comment-start to use rather than signalling an error. Fix regexp.
+ the comment-start to use rather than signaling an error. Fix regexp.
(uncomment-region): Don't leave half-removed comment markers.
2003-04-23 Richard M. Stallman <rms@gnu.org>
diff --git a/lisp/ChangeLog.12 b/lisp/ChangeLog.12
index 1e7ed845b49..2cb3d27d694 100644
--- a/lisp/ChangeLog.12
+++ b/lisp/ChangeLog.12
@@ -7561,7 +7561,7 @@
* pcvs-util.el (cvs-get-buffer-create): Obey `noreuse' even if `name'
doesn't look like a file name.
- * complete.el (PC-expand-many-files): Avoid signalling an error when
+ * complete.el (PC-expand-many-files): Avoid signaling an error when
the current directory doesn't exist. Reported by Michaël Cadilhac.
2006-08-02 Andreas Schwab <schwab@suse.de>
@@ -33362,4 +33362,3 @@ See ChangeLog.11 for earlier changes.
You should have received a copy of the GNU General Public License
along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>.
-
diff --git a/lisp/ChangeLog.13 b/lisp/ChangeLog.13
index 993c51163cb..d1cc345e158 100644
--- a/lisp/ChangeLog.13
+++ b/lisp/ChangeLog.13
@@ -1673,7 +1673,7 @@
x-resolve-font-name.
(x-complement-fontset-spec): Never prepend an ASCII font.
(create-fontset-from-fontset-spec): If a fontset of the same name
- already exists, override it instead of signalling an error. Don't
+ already exists, override it instead of signaling an error. Don't
turn `ascii' into `latin'. Don't update fontset-alias-alist here.
* international/mule-conf.el (unicode-bmp): Delete duplicated
diff --git a/lisp/ChangeLog.14 b/lisp/ChangeLog.14
index c30f0e749ce..e904c1f64b9 100644
--- a/lisp/ChangeLog.14
+++ b/lisp/ChangeLog.14
@@ -7913,7 +7913,7 @@
ignored while matching, replace the entire filename with completion.
* textmodes/flyspell.el (flyspell-check-pre-word-p): Make sure
- flyspell-pre-point is valid to avoid signalling an error in
+ flyspell-pre-point is valid to avoid signaling an error in
post-command-hook.
2008-08-26 Johan Bockgård <bojohan@gnu.org>
@@ -20567,4 +20567,3 @@ See ChangeLog.13 for earlier changes.
You should have received a copy of the GNU General Public License
along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>.
-
diff --git a/lisp/ChangeLog.15 b/lisp/ChangeLog.15
index ed70075754c..aa9c9066dc1 100644
--- a/lisp/ChangeLog.15
+++ b/lisp/ChangeLog.15
@@ -11215,7 +11215,7 @@
* bindings.el (complete-symbol): Move into minibuffer.el.
* minibuffer.el (complete-tag): Move from etags.el. If tags
- completion cannot be performed, return nil instead of signalling
+ completion cannot be performed, return nil instead of signaling
an error.
(completion-at-point): Make it an alias for complete-symbol.
(complete-symbol): Move from bindings.el, and replace with the
@@ -13311,7 +13311,7 @@
2010-01-29 Chong Yidong <cyd@stupidchicken.com>
- * dirtrack.el (dirtrack): Warn instead of signalling error if the
+ * dirtrack.el (dirtrack): Warn instead of signaling error if the
regexp is incorrect (Bug#5476).
2010-01-29 Michael Albinus <michael.albinus@gmx.de>
diff --git a/lisp/ChangeLog.8 b/lisp/ChangeLog.8
index ada6d98ce3d..33970b95558 100644
--- a/lisp/ChangeLog.8
+++ b/lisp/ChangeLog.8
@@ -8317,7 +8317,7 @@
1998-11-11 Sam Steingold <sds@goems.com>
* inf-lisp.el (switch-to-lisp): If no inferior lisp present, call
- `run-lisp' instead of signalling an error.
+ `run-lisp' instead of signaling an error.
1998-11-11 Karl Heuer <kwzh@gnu.org>
@@ -10009,4 +10009,3 @@ See ChangeLog.7 for earlier changes.
You should have received a copy of the GNU General Public License
along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>.
-
diff --git a/lisp/ChangeLog.9 b/lisp/ChangeLog.9
index d2d6409cdd3..d25556ce173 100644
--- a/lisp/ChangeLog.9
+++ b/lisp/ChangeLog.9
@@ -135,7 +135,7 @@
* net/ange-ftp.el (ange-ftp-raw-send-cmd, ange-ftp-wait-not-busy):
Use with-current-buffer.
- (ange-ftp-cd): New arg `noerror' to prevent signalling an error.
+ (ange-ftp-cd): New arg `noerror' to prevent signaling an error.
(ange-ftp-send-cmd): If a `cd' is used (because of a space in the
filename), catch any error that occurs in `ange-ftp-cd'.
If an error happened, don't bother sending `cmd' at all.
@@ -12638,7 +12638,7 @@
(vc-rcs-diff): Only pass `2' to vc-do-command if necessary and
just do a recursive call if we need to retry.
(vc-rcs-checkout): Handle the case where rcs is missing by making
- the buffer read-write if requested and re-signalling the error.
+ the buffer read-write if requested and re-signaling the error.
* vc-cvs.el (vc-cvs-diff): Remove unused and unsupported argument CMP.
diff --git a/lisp/calc/calc-help.el b/lisp/calc/calc-help.el
index 427cf6ba233..66e9c002a47 100644
--- a/lisp/calc/calc-help.el
+++ b/lisp/calc/calc-help.el
@@ -683,7 +683,7 @@ C-w Describe how there is no warranty for Calc."
(calc-do-prefix-help
'("Pack, Unpack, Identity, Diagonal, indeX, Build"
"Row, Column, Subvector; Length; Find; Mask, Expand"
- "Tranpose, Arrange, reVerse; Head, Kons; rNorm"
+ "Transpose, Arrange, reVerse; Head, Kons; rNorm"
"SHIFT + Det, & (inverse), LUD, Trace, conJtrn, Cross"
"SHIFT + Sort, Grade, Histogram; cNorm"
"SHIFT + Apply, Map, Reduce, accUm, Inner-, Outer-prod"
diff --git a/lisp/calendar/icalendar.el b/lisp/calendar/icalendar.el
index 3ffd55db18d..511592d2205 100644
--- a/lisp/calendar/icalendar.el
+++ b/lisp/calendar/icalendar.el
@@ -234,7 +234,7 @@ code for the event, and your personal domain name."
"Enable icalendar debug messages.")
;; ======================================================================
-;; NO USER SERVICABLE PARTS BELOW THIS LINE
+;; NO USER SERVICEABLE PARTS BELOW THIS LINE
;; ======================================================================
(defconst icalendar--weekday-array ["SU" "MO" "TU" "WE" "TH" "FR" "SA"])
@@ -915,7 +915,7 @@ would be \"pm\"."
"Export diary file to iCalendar format.
All diary entries in the file DIARY-FILENAME are converted to iCalendar
format. The result is appended to the file ICAL-FILENAME."
- (interactive "FExport diary data from file:
+ (interactive "FExport diary data from file:
Finto iCalendar file: ")
(save-current-buffer
(set-buffer (find-file diary-filename))
@@ -1557,9 +1557,9 @@ entries. ENTRY-MAIN is the first line of the diary entry."
(defun icalendar--convert-float-to-ical (nonmarker entry-main)
"Convert float diary entry to icalendar format -- partially unsupported!
-
+
FIXME! DAY from diary-float yet unimplemented.
-
+
NONMARKER is a regular expression matching the start of non-marking
entries. ENTRY-MAIN is the first line of the diary entry."
(if (string-match (concat nonmarker "%%\\((diary-float .+\\) ?$") entry-main)
@@ -1794,8 +1794,8 @@ Argument ICAL-FILENAME output iCalendar file.
Argument DIARY-FILENAME input `diary-file'.
Optional argument NON-MARKING determines whether events are created as
non-marking or not."
- (interactive "fImport iCalendar data from file:
-Finto diary file:
+ (interactive "fImport iCalendar data from file:
+Finto diary file:
p")
;; clean up the diary file
(save-current-buffer
diff --git a/lisp/cedet/ede/pconf.el b/lisp/cedet/ede/pconf.el
index 08fc98728e1..05290158189 100644
--- a/lisp/cedet/ede/pconf.el
+++ b/lisp/cedet/ede/pconf.el
@@ -149,7 +149,7 @@ don't do it. A value of nil means to just do it.")
))))
(defmethod ede-proj-configure-recreate ((this ede-proj-project))
- "Delete project THISes configure script and start over."
+ "Delete project THIS's configure script and start over."
(if (not (ede-proj-configure-file this))
(error "Could not determine configure.ac for %S" (object-name this)))
(let ((b (get-file-buffer (ede-proj-configure-file this))))
diff --git a/lisp/cedet/mode-local.el b/lisp/cedet/mode-local.el
index d077dd95f3c..52bfaab5d25 100644
--- a/lisp/cedet/mode-local.el
+++ b/lisp/cedet/mode-local.el
@@ -656,7 +656,7 @@ SYMBOL is a function that can be overridden."
table)
;; Print symbols by type
(when us
- (princ "\n !! Unpecified symbols\n")
+ (princ "\n !! Unspecified symbols\n")
(mapc 'mode-local-print-binding us))
(when mc
(princ "\n ** Mode local constants\n")
diff --git a/lisp/cedet/semantic/bovine/c.el b/lisp/cedet/semantic/bovine/c.el
index af293a10348..49323d24d6a 100644
--- a/lisp/cedet/semantic/bovine/c.el
+++ b/lisp/cedet/semantic/bovine/c.el
@@ -240,7 +240,7 @@ Return the defined symbol as a special spp lex token."
(goto-char (match-end 0))
(looking-at "(")))
(semantic-lex-spp-replacements-enabled nil)
- ;; Temporarilly override the lexer to include
+ ;; Temporarily override the lexer to include
;; special items needed inside a macro
(semantic-lex-analyzer #'semantic-cpp-lexer)
(raw-stream
diff --git a/lisp/cedet/semantic/bovine/el.el b/lisp/cedet/semantic/bovine/el.el
index cfdd4cf6f6c..666624db929 100644
--- a/lisp/cedet/semantic/bovine/el.el
+++ b/lisp/cedet/semantic/bovine/el.el
@@ -534,9 +534,9 @@ Optional argument NOSNARF is ignored."
(t
(setq d (documentation-property
sym 'variable-documentation)))))
- ;; Label it as system doc.. perhaps just for debugging
+ ;; Label it as system doc. perhaps just for debugging
;; purposes.
- (if d (setq d (concat "Sytem Doc: \n" d)))
+ (if d (setq d (concat "System Doc: \n" d)))
))
)
diff --git a/lisp/cedet/srecode/dictionary.el b/lisp/cedet/srecode/dictionary.el
index 521532bed33..272e7693ccd 100644
--- a/lisp/cedet/srecode/dictionary.el
+++ b/lisp/cedet/srecode/dictionary.el
@@ -436,7 +436,7 @@ The root dictionary is usually for a current or active insertion."
;;; COMPOUND VALUE METHODS
;;
-;; Compound values must provide at least the toStriong method
+;; Compound values must provide at least the toString method
;; for use in converting the compound value into sometehing insertable.
(defmethod srecode-compound-toString ((cp srecode-dictionary-compound-value)
diff --git a/lisp/emacs-lisp/eieio-base.el b/lisp/emacs-lisp/eieio-base.el
index 139f5e6a4ce..df57148962f 100644
--- a/lisp/emacs-lisp/eieio-base.el
+++ b/lisp/emacs-lisp/eieio-base.el
@@ -54,7 +54,7 @@ not been set, use values from the parent."
(defmethod slot-unbound ((object eieio-instance-inheritor) class slot-name fn)
"If a slot OBJECT in this CLASS is unbound, try to inherit, or throw a signal.
-SLOT-NAME is the offending slot. FN is the function signalling the error."
+SLOT-NAME is the offending slot. FN is the function signaling the error."
(if (slot-boundp object 'parent-instance)
;; It may not look like it, but this line recurses back into this
;; method if the parent instance's slot is unbound.
diff --git a/lisp/emacs-lisp/eieio.el b/lisp/emacs-lisp/eieio.el
index 352bd245ba4..68a3440b179 100644
--- a/lisp/emacs-lisp/eieio.el
+++ b/lisp/emacs-lisp/eieio.el
@@ -395,7 +395,7 @@ It creates an autoload function for CNAME's constructor."
(aset newc class-parent (cons SC (aref newc class-parent)))
)
- ;; turn this into a useable self-pointing symbol
+ ;; turn this into a usable self-pointing symbol
(set cname cname)
;; Store the new class vector definition into the symbol. We need to
@@ -509,7 +509,7 @@ See `defclass' for more information."
;; save parent in child
(aset newc class-parent (list eieio-default-superclass))))
- ;; turn this into a useable self-pointing symbol
+ ;; turn this into a usable self-pointing symbol
(set cname cname)
;; These two tests must be created right away so we can have self-
diff --git a/lisp/emulation/viper-util.el b/lisp/emulation/viper-util.el
index 24a38236176..c80dd31a8f0 100644
--- a/lisp/emulation/viper-util.el
+++ b/lisp/emulation/viper-util.el
@@ -1112,7 +1112,7 @@ Otherwise return the normal value."
lis)))
-;; Smoothes out the difference between Emacs' unread-command-events
+;; Smooths out the difference between Emacs' unread-command-events
;; and XEmacs unread-command-event. Arg is a character, an event, a list of
;; events or a sequence of keys.
;;
diff --git a/lisp/erc/ChangeLog.01 b/lisp/erc/ChangeLog.01
index 4016586abc7..e189ce26e1d 100644
--- a/lisp/erc/ChangeLog.01
+++ b/lisp/erc/ChangeLog.01
@@ -160,9 +160,9 @@
* debian/control: integrated erc-speak back into erc
- * debian/maint/conffiles, debian/maint/conffiles.in, debian/maint/postinst,
- debian/maint/postinst.in, debian/maint/prerm, debian/maint/prerm.in,
- debian/scripts/install, debian/scripts/install.in, debian/scripts/remove,
+ * debian/maint/conffiles, debian/maint/conffiles.in, debian/maint/postinst,
+ debian/maint/postinst.in, debian/maint/prerm, debian/maint/prerm.in,
+ debian/scripts/install, debian/scripts/install.in, debian/scripts/remove,
debian/scripts/remove.in, debian/scripts/startup.erc-speak:
since erc-speak is gone, resurrect the static files, and update them to support the latest erc
@@ -220,7 +220,7 @@
* erc.el:
* Applied antifuchs/mhp patches, the latest on erc-help, unmodified
* New variable: erc-reuse-buffers default to t.
- * Modified erc-generate-new-buffer-name to use it. it checks if server and port are the same,
+ * Modified erc-generate-new-buffer-name to use it. it checks if server and port are the same,
then one can assume thats the same channel/query target again.
2001-11-23 Mario Lang <mlang@delysid.org>
@@ -238,7 +238,7 @@
* erc.el: * New local variable, erc-announced-server-name
* erc-mode-line-format supports a new symbol, target-and/or-server
- * The mode-line displays the announced server name now (for autojoin later...,
+ * The mode-line displays the announced server name now (for autojoin later...,
greets Adam)
* New macro, erc-server-hook-list for a nice way to define the defcustoms of the erc-server-*-hook's
Thanks go to the guy from #emacs who helped with that
@@ -603,11 +603,11 @@
* debian/control: added the new erc-speak package
- * debian/README.erc-speak, debian/maint/postinst.in, debian/maint/prerm.in,
+ * debian/README.erc-speak, debian/maint/postinst.in, debian/maint/prerm.in,
debian/scripts/install.in, debian/scripts/remove.in:
new file
- * debian/maint/postinst, debian/maint/prerm, debian/scripts/install,
+ * debian/maint/postinst, debian/maint/prerm, debian/scripts/install,
debian/scripts/remove:
removed, superseded by its .in counterpart
@@ -625,7 +625,7 @@
2001-10-23 Mario Lang <mlang@delysid.org>
* erc-speak.el:
- * Added a new personality for channel name announcement, This makes streams of flooded channels much easier to listen to,
+ * Added a new personality for channel name announcement, This makes streams of flooded channels much easier to listen to,
especially if you are on more than one channel simultaneously.
* erc.el:
@@ -643,7 +643,7 @@
* Removed now really obsolete code. Package size reduced by 50%
* erc-speak.el:
- * Very important fix! Now erc-speak is really complete. Messages don't get cut anymore. Be sure to use auditory icons,
+ * Very important fix! Now erc-speak is really complete. Messages don't get cut anymore. Be sure to use auditory icons,
it's reallllly cool now!!!
* erc-speak.el: *** empty log message ***
@@ -655,9 +655,9 @@
* debian/changelog: oops, silly typo
- * debian/changelog, debian/control, debian/copyright,
- debian/maint/conffiles, debian/maint/postinst, debian/maint/prerm,
- debian/rules, debian/scripts/install, debian/scripts/remove,
+ * debian/changelog, debian/control, debian/copyright,
+ debian/maint/conffiles, debian/maint/postinst, debian/maint/prerm,
+ debian/rules, debian/scripts/install, debian/scripts/remove,
debian/scripts/startup:
initial check-in
@@ -666,7 +666,7 @@
* erc.el:
* Changed erc-insert-hook to get two arguments, START and END of the region
which got inserted. CAREFUL! This could break stuff, but it makes the hook
- much more useable.
+ much more usable.
* erc.el:
* Made erc-smiley a new option, currently set to t to showoff this feature. :)
@@ -830,7 +830,7 @@
* Fix for custom problem with :must-match on XEmacs (thanks shapr)
* Added /COUNTRY command using (what-domain) from package mail-extr (shapr)
* Fix for case-sensitivity problem with pals (they are now all downcased)
- * Different (erc-version) function which now can take prefix argument to insert the version information into the current buffer,
+ * Different (erc-version) function which now can take prefix argument to insert the version information into the current buffer,
instead of just displaying it in the minibuffer.
2001-09-10 Mario Lang <mlang@delysid.org>
@@ -1055,4 +1055,3 @@
;; Local Variables:
;; coding: utf-8
;; End:
-
diff --git a/lisp/erc/ChangeLog.03 b/lisp/erc/ChangeLog.03
index 7f82a9bcbe2..74f2ab442b9 100644
--- a/lisp/erc/ChangeLog.03
+++ b/lisp/erc/ChangeLog.03
@@ -323,7 +323,7 @@
* erc.el(erc-modules): Add some more symbols to the set
- * erc.el(erc-modules): * erc.el(erc-modules): Add :greedy t to the set in
+ * erc.el(erc-modules): * erc.el(erc-modules): Add :greedy t to the set in
* erc-dcc.el:
More autoloads which make dcc autoload upon ctcp dcc query received.
@@ -744,7 +744,7 @@
2003-04-27 Damien Elmes <erc@repose.cx>
- * erc.el: * erc.el: erc-modules: added
+ * erc.el: * erc.el: erc-modules: added
2003-04-27 Alex Schroeder <alex@gnu.org>
@@ -1232,7 +1232,7 @@
2003-01-19 Mario Lang <mlang@delysid.org>
- * debian/README.Debian, debian/changelog, debian/scripts/install,
+ * debian/README.Debian, debian/changelog, debian/scripts/install,
debian/scripts/startup.erc, Makefile:
Prepare for 20030119 debian package
@@ -1609,7 +1609,7 @@
POS in any case, otherwise, linewrap occurs.
* erc-dcc.el:
- * Fixed the unibyte-multibyte problem (now a dcc get buffer is (set-buffer-multibyte nil),
+ * Fixed the unibyte-multibyte problem (now a dcc get buffer is (set-buffer-multibyte nil),
and saves correctly (tried with 21.3.50). Thanks to Eli for suggesting it!
* Added :start-time plist property/value to GET handling so that we can calculate elapsed-time.
* Some (unwind-protect (progn (set-buffer ...) ...)) constructs replaced with (with-current-buffer ...)
@@ -1691,12 +1691,12 @@
2003-01-11 Mario Lang <mlang@delysid.org>
- * erc-dcc.el: * erc-dcc.el: * (erc-dcc-do-LIST-command): Fix
+ * erc-dcc.el: * erc-dcc.el: * (erc-dcc-do-LIST-command): Fix
* erc-dcc.el:
* buffer-local variables erc-dcc-sent-marker and erc-dcc-send-confirmed marker removed
Keep This info in erc-dcc-member :sent and :confirmed plist values
- * : * :buffer plist for :type 'SEND removed, since we can get this with (marker-buffer
+ * : * :buffer plist for :type 'SEND removed, since we can get this with (marker-buffer
* erc-dcc-send-connect-hook: New hook, defaults to erc-dcc-send-block and erc-dcc-send-connected, which now prints a msg...
* erc-dcc.el:
@@ -1985,7 +1985,7 @@
(erc-server-PRIVMSG-or-NOTICE): Capitalized first word in message to user.
* erc.el(erc-scroll-to-bottom):
- Temporarilly bind resize-mini-windows to nil so that
+ Temporarily bind resize-mini-windows to nil so that
users who have it set to a non-nil value will not suffer from premature
minibuffer shrinkage due to the below recenter call. I have no idea why
this works, but it solves the problem, and has no negative side effects.
@@ -2160,4 +2160,3 @@ See ChangeLog.02 for earlier changes.
;; Local Variables:
;; coding: utf-8
;; End:
-
diff --git a/lisp/eshell/em-hist.el b/lisp/eshell/em-hist.el
index 993e9d63a94..db5e98062a9 100644
--- a/lisp/eshell/em-hist.el
+++ b/lisp/eshell/em-hist.el
@@ -609,7 +609,7 @@ See also `eshell-read-history'."
history))))
(setq index (1- index)))
(let ((fhist (list t)))
- ;; uniqify the list, but preserve the order
+ ;; uniquify the list, but preserve the order
(while history
(unless (member (car history) fhist)
(nconc fhist (list (car history))))
diff --git a/lisp/files.el b/lisp/files.el
index aac415c1a96..6cf94a89c92 100644
--- a/lisp/files.el
+++ b/lisp/files.el
@@ -2603,7 +2603,7 @@ we don't actually set it to the same mode the buffer already has."
(if (looking-at auto-mode-interpreter-regexp)
(match-string 2)
""))
- ;; Map interpreter name to a mode, signalling we're done at the
+ ;; Map interpreter name to a mode, signaling we're done at the
;; same time.
done (assoc (file-name-nondirectory mode)
interpreter-mode-alist))
@@ -6500,7 +6500,7 @@ Otherwise, trash FILENAME using the freedesktop.org conventions,
(setq tries 0 success t))
(file-already-exists nil))
(setq tries (1- tries))
- ;; Uniqify new-fn. (Some file managers do not
+ ;; Uniquify new-fn. (Some file managers do not
;; like Emacs-style backup file names---e.g. bug
;; 170956 in Konqueror bug tracker.)
(setq new-fn (make-temp-name (concat base-fn "_")))))
diff --git a/lisp/gnus/gnus-uu.el b/lisp/gnus/gnus-uu.el
index 15c3d41bece..743b4580cff 100644
--- a/lisp/gnus/gnus-uu.el
+++ b/lisp/gnus/gnus-uu.el
@@ -41,7 +41,7 @@
:group 'gnus)
(defgroup gnus-extract-view nil
- "Viewwing extracted files."
+ "Viewing extracted files."
:group 'gnus-extract)
(defgroup gnus-extract-archive nil
diff --git a/lisp/gnus/gnus-win.el b/lisp/gnus/gnus-win.el
index a1a8abc3086..ecd5b3b525b 100644
--- a/lisp/gnus/gnus-win.el
+++ b/lisp/gnus/gnus-win.el
@@ -54,7 +54,7 @@
:type 'boolean)
(defcustom gnus-use-frames-on-any-display nil
- "*If non-nil, frames on all displays will be considered useable by Gnus.
+ "*If non-nil, frames on all displays will be considered usable by Gnus.
When nil, only frames on the same display as the selected frame will be
used to display Gnus windows."
:version "22.1"
diff --git a/lisp/info.el b/lisp/info.el
index b8deb3c9c7f..b3bdbc5e5be 100644
--- a/lisp/info.el
+++ b/lisp/info.el
@@ -3328,7 +3328,7 @@ Return a list of matches where each element is in the format
(Info-directory)
;; current-node and current-file are nil when they invoke info-apropos
;; as the first Info command, i.e. info-apropos loads info.el. In that
- ;; case, we use (DIR)Top instead, to avoid signalling an error after
+ ;; case, we use (DIR)Top instead, to avoid signaling an error after
;; the search is complete.
(when (null current-node)
(setq current-file Info-current-file)
diff --git a/lisp/language/vietnamese.el b/lisp/language/vietnamese.el
index 97d5037f3c5..e723e154dc1 100644
--- a/lisp/language/vietnamese.el
+++ b/lisp/language/vietnamese.el
@@ -28,7 +28,7 @@
;;; Commentary:
-;; For Vietnames, the character sets VISCII, VSCII and TCVN-5712 are
+;; For Vietnamese, the character sets VISCII, VSCII and TCVN-5712 are
;; supported.
;;; Code:
diff --git a/lisp/mail/rmail.el b/lisp/mail/rmail.el
index 016fde2bef4..5842f8e741f 100644
--- a/lisp/mail/rmail.el
+++ b/lisp/mail/rmail.el
@@ -2071,7 +2071,7 @@ Call with point at the end of the message."
(defun rmail-add-mbox-headers ()
"Validate the RFC2822 format for the new messages.
Point should be at the first new message.
-An error is signalled if the new messages are not RFC2822
+An error is signaled if the new messages are not RFC2822
compliant.
Unless an Rmail attribute header already exists, add it to the
new messages. Return the number of new messages."
@@ -2440,7 +2440,7 @@ Output a helpful message unless NOMSG is non-nil."
;; the entry for message N+1, which marks
;; the end of message N. (N = number of messages).
(setq messages-head (list (point-marker)))
- (setq messages-after-point
+ (setq messages-after-point
(or (rmail-set-message-counters-counter (min (point) point-save))
0))
@@ -3096,7 +3096,7 @@ but probably is garbage."
;; correspond to the lines in the inbox file.
(goto-char (point-min))
(if header-field
- (progn
+ (progn
(re-search-forward (concat "^" (regexp-quote header-field)) nil t)
(forward-line line-number-within))
(search-forward "\n\n" nil t)
diff --git a/lisp/mail/rmailmm.el b/lisp/mail/rmailmm.el
index d3351255583..f9eaa68c85b 100644
--- a/lisp/mail/rmailmm.el
+++ b/lisp/mail/rmailmm.el
@@ -882,7 +882,7 @@ The other arguments are the same as `rmail-mime-multipart-handler'."
;; We're handling what's left of a truncated message.
(setq next (point-max-marker)))
(t
- ;; The original code signalled an error as below, but
+ ;; The original code signaled an error as below, but
;; this line may be a boundary of nested multipart. So,
;; we just set `next' to nil to skip this line
;; (rmail-mm-get-boundary-error-message
diff --git a/lisp/mpc.el b/lisp/mpc.el
index 40ccb456400..238e8ad68ae 100644
--- a/lisp/mpc.el
+++ b/lisp/mpc.el
@@ -2358,7 +2358,7 @@ This is used so that they can be compared with `eq', which is needed for
(let* ((currenttime (float-time))
(last-time (- currenttime (car mpc-last-seek-time))))
(if (< last-time (* 0.9 repeat-delay))
- nil ;; Trottle
+ nil ;; Throttle
(let* ((status (if (< last-time 1.0)
mpc-status (mpc-cmd-status)))
(songid (cdr (assq 'songid status)))
diff --git a/lisp/net/snmp-mode.el b/lisp/net/snmp-mode.el
index e9783d46ba8..8112ed5b177 100644
--- a/lisp/net/snmp-mode.el
+++ b/lisp/net/snmp-mode.el
@@ -676,7 +676,7 @@ controls whether case is significant."
;; v2 SMI TEXTUAL-CONVENTION macro template
;;
(tempo-define-template "snmpv2-textual-convention"
- '(> (P "Texual Convention Type: ") " ::= TEXTUAL-CONVENTION" n>
+ '(> (P "Textual Convention Type: ") " ::= TEXTUAL-CONVENTION" n>
"STATUS "
(if tempo-interactive
(snmp-completing-read "Status: " snmp-mode-status-list nil t)
diff --git a/lisp/net/soap-client.el b/lisp/net/soap-client.el
index d6949e4d250..74f51d148ef 100644
--- a/lisp/net/soap-client.el
+++ b/lisp/net/soap-client.el
@@ -373,7 +373,7 @@ binding) but the same name."
(defstruct (soap-sequence-type (:include soap-element))
parent ; OPTIONAL WSDL-TYPE name
- elements ; LIST of SOAP-SEQUCENCE-ELEMENT
+ elements ; LIST of SOAP-SEQUENCE-ELEMENT
)
(defstruct (soap-array-type (:include soap-element))
diff --git a/lisp/net/xesam.el b/lisp/net/xesam.el
index 56e9cb68c61..efb2cdd6166 100644
--- a/lisp/net/xesam.el
+++ b/lisp/net/xesam.el
@@ -409,7 +409,7 @@ If there is no registered search engine at all, the function returns `nil'."
(setq vendor-id (xesam-get-property engine "vendor.id")
hit-fields (xesam-get-property engine "hit.fields"))
- ;; Ususally, `hit.fields' shall describe supported fields.
+ ;; Usually, `hit.fields' shall describe supported fields.
;; That is not the case now, so we set it ourselves.
;; Hopefully, this will change later.
(setq hit-fields
diff --git a/lisp/net/zeroconf.el b/lisp/net/zeroconf.el
index d801a4c094c..9060e091587 100644
--- a/lisp/net/zeroconf.el
+++ b/lisp/net/zeroconf.el
@@ -486,7 +486,7 @@ TYPE. The resulting list has the format
(nth 9 (zeroconf-resolve-service service)))
-;;; Services signalling.
+;;; Services signaling.
;; Register for the service type browser. Service registrations will
;; happen in `zeroconf-service-type-browser-handler', when there is an
diff --git a/lisp/org/ChangeLog b/lisp/org/ChangeLog
index f6bd1ffa2d4..704da5fa68e 100644
--- a/lisp/org/ChangeLog
+++ b/lisp/org/ChangeLog
@@ -5020,7 +5020,7 @@
with code implementing the writing of graohical output to file.
(org-babel-execute:R): Use `org-babel-R-graphical-output-file' to
determine whether R is taking responsibility for writing output to
- file; if so, this is signalled to ob.el by returning a nil result.
+ file; if so, this is signaled to ob.el by returning a nil result.
2011-07-28 Dan Davison <dandavison7@gmail.com>
@@ -18037,4 +18037,3 @@
You should have received a copy of the GNU General Public License
along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>.
-
diff --git a/lisp/org/org-list.el b/lisp/org/org-list.el
index 866176e4e8f..2fe512329ca 100644
--- a/lisp/org/org-list.el
+++ b/lisp/org/org-list.el
@@ -2642,7 +2642,7 @@ If a region is active, all items inside will be moved."
(defvar org-tab-ind-state)
(defun org-cycle-item-indentation ()
"Cycle levels of indentation of an empty item.
-The first run indents the item, if applicable. Subsequents runs
+The first run indents the item, if applicable. Subsequent runs
outdent it at meaningful levels in the list. When done, item is
put back at its original position with its original bullet.
diff --git a/lisp/org/org.el b/lisp/org/org.el
index da39aa189ba..10531b07325 100644
--- a/lisp/org/org.el
+++ b/lisp/org/org.el
@@ -2681,7 +2681,7 @@ When this variable is set to t, the date/time prompt will not let
you specify dates outside the 1970-2037 range, so it is certain that
these dates will work in whatever version of Emacs you are
running, and also that you can move a file from one Emacs implementation
-to another. WHenever Org is forcing the year for you, it will display
+to another. Whenever Org is forcing the year for you, it will display
a message and beep.
When this variable is nil, Org will check if the date is
diff --git a/lisp/progmodes/cc-cmds.el b/lisp/progmodes/cc-cmds.el
index e59fdc16af7..151dbd0c76e 100644
--- a/lisp/progmodes/cc-cmds.el
+++ b/lisp/progmodes/cc-cmds.el
@@ -2969,7 +2969,7 @@ A prefix argument acts as a repeat count. With a negative argument,
move backward across a preprocessor conditional.
If there aren't enough conditionals after \(or before) point, an
-error is signalled.
+error is signaled.
\"#elif\" is treated like \"#else\" followed by \"#if\", except that
the nesting level isn't changed when tracking subconditionals.
@@ -4094,7 +4094,7 @@ command to conveniently insert and align the necessary backslashes."
; (or (<= (- (cdr c-lit-limits) 2) (point))
; 2010-10-17 Construct removed.
; (or (< (- (cdr c-lit-limits) 2) (point))
- (and
+ (and
(search-forward-regexp
(concat "\\=[ \t]*\\(" c-current-comment-prefix "\\)")
(- (cdr c-lit-limits) 2) t)
diff --git a/lisp/progmodes/cc-defs.el b/lisp/progmodes/cc-defs.el
index 8632807f2b8..fb9fd406ef8 100644
--- a/lisp/progmodes/cc-defs.el
+++ b/lisp/progmodes/cc-defs.el
@@ -555,7 +555,7 @@ certain situations."
`(c-forward-sexp ,(if (numberp count) (- count) `(- ,count))))
(defmacro c-safe-scan-lists (from count depth &optional limit)
- "Like `scan-lists' but returns nil instead of signalling errors
+ "Like `scan-lists' but returns nil instead of signaling errors
for unbalanced parens.
A limit for the search may be given. FROM is assumed to be on the
@@ -760,7 +760,7 @@ be after it."
;; non-nil if point (or the optional parameter POS) is at a VS, nil otherwise.
;;
;; The language specific function might well do extensive analysis of the
-;; source text, and may use a cacheing scheme to speed up repeated calls.
+;; source text, and may use a caching scheme to speed up repeated calls.
;;
;; The "virtual semicolon" lies just after the last non-ws token on the line.
;; Like POINT, it is considered to lie between two characters. For example,
@@ -784,7 +784,7 @@ be after it."
;; `c-beginning-of-statement-1'. `c-vsemi-status-unknown-p' may not itself
;; call `c-beginning-of-statement-1'.
;;
-;; The macro `c-vsemi-status-unknown-p' will typically check the cacheing
+;; The macro `c-vsemi-status-unknown-p' will typically check the caching
;; scheme used by the `c-at-vsemi-p-fn', hence the name - the status is
;; "unknown" if there is no cache entry current for the line.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
diff --git a/lisp/progmodes/gdb-mi.el b/lisp/progmodes/gdb-mi.el
index e47ba3c92f3..c88727c721c 100644
--- a/lisp/progmodes/gdb-mi.el
+++ b/lisp/progmodes/gdb-mi.el
@@ -350,7 +350,7 @@ automatically.
This setting is used in non-stop mode only. In all-stop mode,
Emacs always switches to the thread which caused the stop."
- ;; exited, exited-normally and exited-signalled are not
+ ;; exited, exited-normally and exited-signaled are not
;; thread-specific stop reasons and therefore are not included in
;; this list
:type '(choice
diff --git a/lisp/progmodes/idlwave.el b/lisp/progmodes/idlwave.el
index 95f67a6bf66..d3770247c60 100644
--- a/lisp/progmodes/idlwave.el
+++ b/lisp/progmodes/idlwave.el
@@ -7206,7 +7206,7 @@ If these don't exist, a letter in the string is automatically selected."
;;----------------------------------------------------------------------
;;; ------------------------------------------------------------------------
-;;; Stucture parsing code, and code to manage class info
+;;; Structure parsing code, and code to manage class info
;;
;; - Go again over the documentation how to write a completion
diff --git a/lisp/progmodes/verilog-mode.el b/lisp/progmodes/verilog-mode.el
index f7cb1318dc0..9ef7440f8da 100644
--- a/lisp/progmodes/verilog-mode.el
+++ b/lisp/progmodes/verilog-mode.el
@@ -2709,7 +2709,7 @@ either is ok to parse as a non-comment, or `verilog-insert' was used."
(remove-text-properties (point-min) (point-max) '(v-cmt nil))
(verilog-scan-region (point-min) (point-max))
(setq verilog-scan-cache-tick (buffer-chars-modified-tick))
- (when verilog-debug (message "Scaning... done"))))))
+ (when verilog-debug (message "Scanning... done"))))))
(defun verilog-inside-comment-p ()
"Check if point inside a comment.
@@ -11958,7 +11958,7 @@ Files are checked based on `verilog-library-flags'."
(mouse-set-point event)
(verilog-load-file-at-point t)))
-;; ffap isn't useable for Verilog mode. It uses library paths.
+;; ffap isn't usable for Verilog mode. It uses library paths.
;; so define this function to do more or less the same as ffap
;; but first resolve filename...
(defun verilog-load-file-at-point (&optional warn)
diff --git a/lisp/view.el b/lisp/view.el
index ef865007332..6955fbdfad8 100644
--- a/lisp/view.el
+++ b/lisp/view.el
@@ -925,7 +925,7 @@ for highlighting the match that is found."
(defun view-search (times regexp)
;; This function does the job for all the View-search- commands.
- ;; Search for the TIMESt match for REGEXP. If TIMES is negative
+ ;; Search for the TIMESth match for REGEXP. If TIMES is negative
;; search backwards. If REGEXP is nil use `view-last-regexp'.
;; Characters "!" and "@" have a special meaning at the beginning of
;; REGEXP and are removed from REGEXP before the search "!" means
diff --git a/lisp/window.el b/lisp/window.el
index 7b16d6b886f..ddb29b95856 100644
--- a/lisp/window.el
+++ b/lisp/window.el
@@ -5409,7 +5409,7 @@ by `recenter-positions'."
;;; of buffer).
(defcustom scroll-error-top-bottom nil
- "Move point to top/bottom of buffer before signalling a scrolling error.
+ "Move point to top/bottom of buffer before signaling a scrolling error.
A value of nil means just signal an error if no more scrolling possible.
A value of t means point moves to the beginning or the end of the buffer
\(depending on scrolling direction) when no more scrolling possible.
diff --git a/lisp/woman.el b/lisp/woman.el
index 078acfc0362..4999a08bb72 100644
--- a/lisp/woman.el
+++ b/lisp/woman.el
@@ -1439,7 +1439,7 @@ The cdr of each alist element is the path-index / filename."
(push (woman-topic-all-completions-1 dir path-index)
files))
(setq path-index (1+ path-index)))
- ;; Uniquefy topics:
+ ;; Uniquify topics:
;; Concatenate all lists with a single nconc call to
;; avoid retraversing the first lists repeatedly -- dak
(woman-topic-all-completions-merge
diff --git a/lisp/emacs-lisp/ert.el b/lisp/emacs-lisp/ert.el
index 2afe42dc070..8b64cd84bb1 100644
--- a/lisp/emacs-lisp/ert.el
+++ b/lisp/emacs-lisp/ert.el
@@ -248,7 +248,7 @@ Emacs bug 6581 at URL `http://debbugs.gnu.org/cgi/bugreport.cgi?bug=6581'."
;; We disallow nil since `ert-test-at-point' and related functions
;; want to return a test name, but also need an out-of-band value
;; on failure. Nil is the most natural out-of-band value; using 0
;; or "" or signalling an error would be too awkward.
;;
;; Note that nil is still a valid value for the `name' slot in
;; ert-test objects. It designates an anonymous test.
@@ -448,7 +448,7 @@ arguments: INNER-FORM and FORM-DESCRIPTION-FORM, where INNER-FORM
is an expression equivalent to FORM, and FORM-DESCRIPTION-FORM is
an expression that returns a description of FORM. INNER-EXPANDER
should return code that calls INNER-FORM and performs the checks
-and error signalling specific to the particular variant of
+and error signaling specific to the particular variant of
`should'. The code that INNER-EXPANDER returns must not call
FORM-DESCRIPTION-FORM before it has called INNER-FORM."
(lexical-let ((inner-expander inner-expander))
@@ -489,17 +489,17 @@ Returns nil."
Determines whether CONDITION matches TYPE and EXCLUDE-SUBTYPES,
and aborts the current test as failed if it doesn't."
- (let ((signalled-conditions (get (car condition) 'error-conditions))
+ (let ((signaled-conditions (get (car condition) 'error-conditions))
(handled-conditions (etypecase type
(list type)
(symbol (list type)))))
- (assert signalled-conditions)
- (unless (ert--intersection signalled-conditions handled-conditions)
+ (assert signaled-conditions)
+ (unless (ert--intersection signaled-conditions handled-conditions)
(ert-fail (append
(funcall form-description-fn)
(list
:condition condition
- :fail-reason (concat "the error signalled did not"
+ :fail-reason (concat "the error signaled did not"
" have the expected type")))))
(when exclude-subtypes
(unless (member (car condition) handled-conditions)
@@ -507,7 +507,7 @@ and aborts the current test as failed if it doesn't."
(funcall form-description-fn)
(list
:condition condition
- :fail-reason (concat "the error signalled was a subtype"
+ :fail-reason (concat "the error signaled was a subtype"
" of the expected type"))))))))
;; FIXME: The expansion will evaluate the keyword args (if any) in
@@ -515,7 +515,7 @@ and aborts the current test as failed if it doesn't."
(defmacro* should-error (form &rest keys &key type exclude-subtypes)
"Evaluate FORM and check that it signals an error.
-The error signalled needs to match TYPE. TYPE should be a list
+The error signaled needs to match TYPE. TYPE should be a list
of condition names. (It can also be a non-nil symbol, which is
equivalent to a singleton list containing that symbol.) If
EXCLUDE-SUBTYPES is nil, the error matches TYPE if one of its
@@ -523,7 +523,7 @@ condition names is an element of TYPE. If EXCLUDE-SUBTYPES is
non-nil, the error matches TYPE if it is an element of TYPE.
If the error matches, returns (ERROR-SYMBOL . DATA) from the
-error. If not, or if no error was signalled, abort the test as
+error. If not, or if no error was signaled, abort the test as
failed."
(unless type (setq type ''error))
(ert--expand-should
@@ -2120,7 +2120,7 @@ To be used in the ERT results buffer."
EWOC-FN specifies the direction and should be either `ewoc-prev'
or `ewoc-next'. If there are no more nodes in that direction, an
-error is signalled with the message ERROR-MESSAGE."
+error is signaled with the message ERROR-MESSAGE."
(loop
(setq node (funcall ewoc-fn ert--results-ewoc node))
(when (null node)
@@ -248,7 +248,7 @@ Emacs bug 6581 at URL `http://debbugs.gnu.org/cgi/bugreport.cgi?bug=6581'."
;; want to return a test name, but also need an out-of-band value
;; on failure. Nil is the most natural out-of-band value; using 0
- ;; or "" or signalling an error would be too awkward.
+ ;; or "" or signaling an error would be too awkward.
;;
;; Note that nil is still a valid value for the `name' slot in